@@ -290,7 +290,6 @@ static int greport_compute_yaxis(struct PlotStruct *pdata,struct GraphDataStruct
 	double symin,symax;
 	double range;
 	double yscale;
-	double ymag;
 
 	if (pdata->ymin<0.) {
 		debuga(_("Minimum for Y scale of the graph is out of range: %"PRId64"\n"),(int64_t)pdata->ymin);
@@ -306,7 +305,6 @@ static int greport_compute_yaxis(struct PlotStruct *pdata,struct GraphDataStruct
 		case PTG_LinBin:
 			symin=(double)pdata->ymin;
 			symax=(double)pdata->ymax;
-			ymag=1000.;
 			break;
 
 		case PTG_LogBin:
@@ -315,13 +313,11 @@ static int greport_compute_yaxis(struct PlotStruct *pdata,struct GraphDataStruct
 			else
 				symin=0.;
 			symax=log(pdata->ymax);
-			ymag=1000.;
 			break;
 
 		case PTG_Time:
 			symin=(double)pdata->ymin;
 			symax=(double)pdata->ymax;
-			ymag=1.;
 			break;
 
 		default:
@@ -665,7 +661,6 @@ void greport_day(const struct userinfostruct *uinfo)
 	FILE *fp_in, *fp_ou;
 	char wdirname[MAXLEN];
 	char buf[MAXLEN];
-	char colsep;
 	int day;
 	long long int llday;
 	long long int bytes;
@@ -709,7 +704,6 @@ void greport_day(const struct userinfostruct *uinfo)
 			exit(EXIT_FAILURE);
 		}
 		if ((datetimeby & DATETIME_BYTE)!=0) {
-			colsep=((datetimeby & DATETIME_ELAP)!=0) ? '\t' : '\0';
 			if (getword_atoll(&bytes,&gwarea,'\t')<0) {
 				debuga(_("Invalid number of bytes in file %s\n"),wdirname);
 				exit(EXIT_FAILURE);
