@@ -526,7 +526,7 @@ void htmlrel(void)
 		}
 
 		if(PerUserLimit > 0) {
-			if(tnbytes > (PerUserLimit*1000000)) {
+			if ((int)(tnbytes/1000000LLU) > PerUserLimit) {
 				limit_flag=0;
 				if(access(PerUserLimitFile, R_OK) == 0) {
 					if((fp_usr = fopen(PerUserLimitFile, "r")) == 0) {
