@@ -538,7 +538,7 @@ static int Alias_Store(char *buf)
 	unsigned short int ipv6[8];
 	int nbits;
 	const char *next;
-	int Error;
+	int Error=-10;//compiler pacifier: uninitialized variable
 	
 	if (strncasecmp(buf,"re:",3)==0) {
 #ifdef USE_PCRE
